# caraml

**Car**efree **A**ccelerated **M**essaging **L**ibrary.

- Carefree: user-friendly API on top of ZeroMQ that makes distributed programming much simpler and less error-prone. 

- Accelerated: fast in-memory serialization and deserialization with Apache Arrow. 

## More docs coming soon

